@@ -81,6 +81,8 @@ class Element:
         return True
 
     def make(self):
+        if self.parser.debug:
+            print(self.name)
         if self.useFunc[self.name][1]:
             self.useFunc[self.name][1]()
 
@@ -112,6 +114,9 @@ class Element:
             #非字符串则表示使用自定义函数
             params.extend([self, ob])
 
+        if self.parser.debug:
+            print(f, params)
+
         f(*params)
 
     def addSubscribe(self, ob, c):
