@@ -1,4 +1,4 @@
-import asyncio, threading
+import asyncio, threading, functools
 
 class ObservableBase:
     def __init__(self):
@@ -108,7 +108,22 @@ class BoolFormat:
     def __mod__(self, v):
         return self.format % (self.arr[0] if v else self.arr[1])
 
-class Debounce:
+class DebounceAsync:
+    def __init__(self, interval):
+        self.interval = interval
+        self.debounced = None
+        self.loop = asyncio.get_event_loop()
+
+    def __call__(self, func):
+        def decorator(*args, **kwargs):
+            if self.debounced is not None:
+                self.debounced.cancel()
+            wrapped = functools.partial(func, **kwargs)
+            self.debounced = self.loop.call_later(self.interval, wrapped, *args)
+
+        return decorator
+
+class DebounceThread:
     def __init__(self, interval):
         self.interval = interval
         self.debounced = None
@@ -119,15 +134,16 @@ class Debounce:
                 self.debounced.cancel()
             self.debounced = threading.Timer(self.interval, func, args, kwargs)
             self.debounced.start()
+
         return decorator
 
 
 if __name__ == "__main__":
-    import time
+    import time, threading
     def testDebounce(v):
         print(v)
 
-    @Debounce(3)
+    @DebounceAsync(3)
     def changeB(v):
         b.value = v
 
@@ -136,7 +152,12 @@ if __name__ == "__main__":
     a.subscribe(changeB)
     b.subscribe(testDebounce)
 
-    a.value = 1
-    time.sleep(4)
-    a.value = 3
-    time.sleep(5)
\ No newline at end of file
+    async def test():
+        a.value = 1
+        await asyncio.sleep(2)
+
+        a.value = 3
+        await asyncio.sleep(5)
+
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(test())
\ No newline at end of file
